
GoldsellerViewModel = class(ViewModelBase);

-- Initializes a new GoldsellerViewModel instance
function GoldsellerViewModel:Constructor(filterEngine)
	ViewModelBase.Constructor(self);
	
	-- private
	self.Engine = filterEngine;
	self.Policy = self.Engine:GetPolicy("GoldsellerPolicy");
	
	-- public
	self.Title = "Goldseller Policy";
	self.HeuristicWords = "";
	self.HeuristicSymbols = "";
	self.Threshold = 0;

	-- update data so that we have some values on start up
	self:UpdateTables();
	self:UpdateThreshold();

	self.ApplyCommand = function()
		self.Policy:SetHeuristicTables(self.HeuristicWords, self.HeuristicSymbols);
		self.Policy:SetThreshold(self.Threshold);
	end;

	self:AddCallback(self.Policy, "HeuristicTablesChanged", function()
		self:UpdateTables();
	end);

	self:AddCallback(self.Policy, "ThresholdChanged", function()
		self:UpdateThreshold();
	end);
end

-- public
function GoldsellerViewModel:SetHeuristicWords(words)
	self:SetProperty("HeuristicWords", words);
end

-- public
function GoldsellerViewModel:SetHeuristicSymbols(symbols)
	self:SetProperty("HeuristicSymbols", symbols);
end

-- public
function GoldsellerViewModel:SetThreshold(threshold)
	self:SetProperty("Threshold", threshold);
end

-- private
function GoldsellerViewModel:UpdateTables()
	self:SetHeuristicWords(table.concat(self.Policy.Data.SpamHeuristic.Words, " "));
	self:SetHeuristicSymbols(table.concat(self.Policy.Data.SpamHeuristic.Symbols, " "));
end

-- private
function GoldsellerViewModel:UpdateThreshold()
	self:SetThreshold(self.Policy.Data.SpamHeuristic.Threshold);
end
